@@ -5,11 +5,11 @@ class Host:
   app = Flask('')
 
   @app.route('/')
-  def main(self):
+  def main():
     return 'The project is running. Please copy the link and host it on uptimerobot.com'
     
   def run(self, port):
     app.run(host="0.0.0.0", port=port)
   def keep_running(self, port = 8080):
-    server = Thread(target=run(port=port))
+    server = Thread(target=self.run(port=port))
     server.start()
\ No newline at end of file
